function DstateSensitivityDt = odeLorenzWithSensitivity(t,stateAndSensitivity,param)
%ODELORENZ Lorenz equation, famous for its chaotic attractor
% see its wikipedia page

stateVar = stateAndSensitivity(:,1);
x = stateVar(1);
y = stateVar(2);
z = stateVar(3);

DsDs0 = stateAndSensitivity(4:end); % 9 x 1 vector
DsDs0 = reshape(DsDs0,3,3); % convert to 3x3 matrix

dxdt = param.sigma*(y-x);
dydt = x*(param.rho-z)-y;
dzdt = x*y-param.beta*z;

DstateVarDt = [dxdt; dydt; dzdt];

DfDs = [-param.sigma param.sigma 0; ...
    param.rho -1 x;
    y x -param.beta];

DsDs0Dot = DfDs*DsDs0;

DstateSensitivityDt = ...
    [DstateVarDt; reshape(DsDs0Dot,9,1)];

end